/**
 * Dragon - SOA Governance Platform.
 * Copyright (c) 2008 EBM Websourcing, http://www.ebmwebsourcing.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * Endpoint.java
 * -------------------------------------------------------------------------
 */

package org.ow2.dragon.connection.api.to;

import java.util.HashMap;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
import javax.xml.namespace.QName;

/**
 * A Service Endpoint representation with its unique name (a {@link QName}),
 * description (the WSDL description that contains this endpoint description),
 * etc.
 * 
 * @author ofabre - eBM Websourcing
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(namespace = "http://to.api.connection.dragon.ow2.org/", name = "Endpoint")
public class Endpoint {

    @XmlAttribute(name = "name")
    private QName name;

    @XmlElement(name = "wsdlDescription")
    private String wsdlDescription;
    
    /* Map passing
     * JAXB also does not support Maps.  It handles Lists great, but Maps are
     * not supported directly.  They also require use of a XmlAdapter to map
     * the maps into beans that JAXB can use. 
     */
    @XmlJavaTypeAdapter(HashMapAdapter.class)
    @XmlElement
    private HashMap<String, String> wsdlDescriptionImports;

    public String getWsdlDescription() {
        return wsdlDescription;
    }

    public void setWsdlDescription(String wsdlDescription) {
        this.wsdlDescription = wsdlDescription;
    }

    public QName getName() {
        return name;
    }

    public void setName(QName name) {
        this.name = name;
    }

    public HashMap<String, String> getWsdlDescriptionImports() {
        return wsdlDescriptionImports;
    }

    public void setWsdlDescriptionImports(HashMap<String, String> wsdlDescriptionImports) {
        this.wsdlDescriptionImports = wsdlDescriptionImports;
    }

}
